ZelloEvent class sealed
Sealed hierarchy of native -> Dart streaming events.
Use a switch (Dart 3 pattern matching) to handle exhaustively:
switch (event) {
ZelloConnectionStateChanged(:final state) => ...,
ZelloIncomingVoiceStarted(:final from, :final channel) => ...,
ZelloIncomingVoiceStopped() => ...,
ZelloIncomingTextMessage(:final message) => ...,
ZelloOutgoingTalkStateChanged(:final isTalking) => ...,
ZelloChannelStatusChanged(:final channel, :final isConnected) => ...,
ZelloErrorEvent(:final code, :final message) => ...,
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited